@@ -5,15 +5,15 @@ from ..extractor import *
 from ..common import *
 
 def url_to_module(url):
-    video_host = r1(r'http://([^/]+)/', url)
-    video_url = r1(r'http://[^/]+(.*)', url)
+    video_host = r1(r'https?://([^/]+)/', url)
+    video_url = r1(r'https?://[^/]+(.*)', url)
     assert video_host and video_url, 'invalid url: ' + url
-    
+
     if video_host.endswith('.com.cn'):
         video_host = video_host[:-3]
     domain = r1(r'(\.[^.]+\.[^.]+)$', video_host) or video_host
     assert domain, 'unsupported url: ' + url
-    
+
     k = r1(r'([^.]+)', domain)
     downloads = {
         '163': netease,
@@ -41,6 +41,7 @@ def url_to_module(url):
         'kankanews': bilibili,
         'ku6': ku6,
         'letv': letv,
+        'magisto': magisto,
         'miomio': miomio,
         'mixcloud': mixcloud,
         'nicovideo': nicovideo,
@@ -57,6 +58,7 @@ def url_to_module(url):
         'vid48': vid48,
         'vimeo': vimeo,
         'vine': vine,
+        'vk': vk,
         'xiami': xiami,
         'yinyuetai': yinyuetai,
         'youku': youku,
@@ -66,7 +68,7 @@ def url_to_module(url):
         #TODO
     }
     if k in downloads:
-        return downloads[k]
+        return downloads[k], url
     else:
         import http.client
         conn = http.client.HTTPConnection(video_host)
@@ -76,21 +78,15 @@ def url_to_module(url):
         if location is None:
             raise NotImplementedError(url)
         else:
-            return url_to_module(location), location
+            return url_to_module(location)
 
-def any_download(url, output_dir = '.', merge = True, info_only = False):
-    try:
-        m, url = url_to_module(url)
-    except:
-        m = url_to_module(url)
-    m.download(url, output_dir = output_dir, merge = merge, info_only = info_only)
+def any_download(url, output_dir='.', merge=True, info_only=False):
+    m, url = url_to_module(url)
+    m.download(url, output_dir=output_dir, merge=merge, info_only=info_only)
 
-def any_download_playlist(url, output_dir = '.', merge = True, info_only = False):
-    try:
-        m, url = url_to_module(url)
-    except:
-        m = url_to_module(url)
-    m.download_playlist(url, output_dir = output_dir, merge = merge, info_only = info_only)
+def any_download_playlist(url, output_dir='.', merge=True, info_only=False):
+    m, url = url_to_module(url)
+    m.download_playlist(url, output_dir=output_dir, merge=merge, info_only=info_only)
 
 def main():
     script_main('you-get', any_download, any_download_playlist)
